Changes
=======

0.1.6 (2021-09-09)
------------------

* Build dist

0.1.7 (2021-09-14)
------------------

* Create XFormSubmit dir if not present
* Adapt button Modify -> Edit

0.1.9 (2021-09-14)
------------------

* rm _set_today in model
* Add /odk to openrosa url

0.2.0 (2021-09-17)
------------------

* Remove dependency on lxml
* Remove modifications on xml_content field
* Rebuild initial migration
* Add admin management
* Add use of AUTH_USER_MODEL in settings.py
* Add delete button on submitted forms

0.2.1 (2021-10-05)
------------------

* Add migrations on PyPi
* Add is_odk_admin property on user model